import * as AWS from 'aws-sdk';
import * as M from 'that-simple-model';
import * as O from 'that-simple-objectstore';
/**
 * ObjectStore for persisting to DynamoDB
 */
export declare class DynamoObjectStore implements O.IObjectStore {
    /**
     * The connection to the dynamodb service
     */
    private _dynamodb;
    /**
     * An instance of a document client
     */
    private _docClient;
    constructor(config: AWS.DynamoDB.ClientConfiguration);
    /**
     * Create a simple/standard DynamoDB table
     */
    construct<T extends M.IModel>(cls: M.IModelClass<T>): Promise<void>;
    /**
     * Creates/updates an item in the dynamodb
     */
    put<T extends M.IModel>(item: T): Promise<T>;
    /**
     * Returns an items from the dynamodb datastore
     */
    get<T extends M.IModel>(cls: M.IModelClass<T>, partitionKey: string | number, sortKey?: string | number): Promise<T>;
    /**
     * Removes an item from the dynamodb datastore
     */
    query<T extends M.IModel>(cls: M.IModelClass<T>, query?: O.IObjectStoreQueryOptions<T>): Promise<O.IObjectStoreQueryResult<T>>;
    /**
     * Removes an item from the dynamodb datastore
     */
    remove<T extends M.IModel>(item: T): Promise<void>;
}
